[krb5-auth-dialog] Add no-persistence test option



commit b41a0532379e5be2a96577c6c66ae20d956403d3
Author: Guido Günther <agx sigxcpu org>
Date:   Sat Nov 1 21:20:44 2014 +0100

    Add no-persistence test option
    
    This allows us to test notification systems without persistence.
    We can then e.g. embed it into an Xnest sessions's xfce4-panel.

 src/ka-applet.c |   11 +++++++++--
 1 files changed, 9 insertions(+), 2 deletions(-)
---
diff --git a/src/ka-applet.c b/src/ka-applet.c
index cc779db..ed7c367 100644
--- a/src/ka-applet.c
+++ b/src/ka-applet.c
@@ -56,8 +56,9 @@ enum {
 
 
 enum {
-    KA_DEBUG_NO_APP_MENU = 1,   /* Disable gtk-shell-shows-app-menu gtk setting */
-    KA_DEBUG_NO_HEADER_BAR = 2, /* Disable header-bar setting */
+    KA_DEBUG_NO_APP_MENU    = 1,  /* Disable gtk-shell-shows-app-menu gtk setting */
+    KA_DEBUG_NO_HEADER_BAR  = 2,  /* Disable header-bar setting */
+    KA_DEBUG_NO_PERSISTENCE = 4,  /* notification system does not support persistence */
 };
 
 
@@ -295,6 +296,8 @@ ka_applet_handle_debug(KaApplet *self)
                           "gtk-dialogs-use-header", FALSE,
                           NULL);
             self->priv->debug_flags |= KA_DEBUG_NO_HEADER_BAR;
+        } else if (!g_strcmp0(*opt, "no-persistence")) {
+            self->priv->debug_flags |= KA_DEBUG_NO_PERSISTENCE;
         } else {
             g_warning ("Unhandled debug options %s", *opt);
         }
@@ -1177,6 +1180,10 @@ ka_ns_check_persistence (KaApplet *self)
     gint    seconds = 5;
 
     self->priv->ns_persistence = FALSE;
+
+    if (self->priv->debug_flags & KA_DEBUG_NO_PERSISTENCE)
+        return;
+
     do {
         caps = notify_get_server_caps ();
         if (caps == NULL)


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]